<?php
/**
 * The template for displaying the Featured Content
 *
 * @package Catch Themes
 * @subpackage Parallax Frame Pro
 * @since Parallax Frame 1.0
 */



if ( !function_exists( 'parallax_frame_hero_content_display' ) ) :
/**
* Add Featured content.
*
* @uses action hook parallax_frame_before_content.
*
* @since Parallax Frame 1.0
*/
function parallax_frame_hero_content_display() {
	//parallax_frame_flush_transients();
	global $wp_query;

	// get data value from options
	$options        = parallax_frame_get_theme_options();
	$enable_content = $options['hero_content_option'];
	$content_select = $options['hero_content_type'];

	// Front page displays in Reading Settings
	$page_on_front 	= get_option('page_on_front') ;
	$page_for_posts = get_option('page_for_posts');


	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();
	if ( 'entire-site' == $enable_content  || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && 'homepage' == $enable_content  ) ) {
		if ( ( !$output = get_transient( 'parallax_frame_hero_content' ) ) ) {
			echo '<!-- refreshing cache -->';

			$classes[] = $content_select ;

			$output ='
				<section id="hero-section" class="' . implode( ' ', $classes ) . '">
					<div class="wrapper">';
						// Select content
						if ( 'demo-hero-content' == $content_select ) {
							$output .= parallax_frame_demo_hero_content();
						}
						elseif ( 'hero-post-content' == $content_select || 'hero-page-content' == $content_select || 'hero-category-content' == $content_select ) {
							$output .= parallax_frame_post_page_category_hero_content( $options );
						}
						elseif ( 'hero-custom-content' == $content_select  ) {
							$output .= parallax_frame_custom_hero_content( $options );
						}

				$output .='
					</div><!-- .wrapper -->
				</section><!-- #hero-section -->';

			set_transient( 'parallax_frame_hero_content', $output, 86940 );
		}
	echo $output;
	}
}
endif;
add_action( 'parallax_frame_before_content', 'parallax_frame_hero_content_display', 20 );


if ( ! function_exists( 'parallax_frame_demo_hero_content' ) ) :
/**
 * This function to display hero posts content
 *
 * @get the data value from customizer options
 *
 * @since parallaxframe 1.0
 *
 */
function parallax_frame_demo_hero_content() {
	return '
	<article class="post-11 page type-page status-publish has-post-thumbnail hentry" id="post-11">
		<figure class="featured-image">
	    	<a href="#" rel="bookmark">
	        	<img width="600" height="400" alt="" class="wp-post-image" src="'.get_template_directory_uri() . '/images/gallery/about-600x400.jpg">
	        </a>
		</figure>
		<div class="entry-container">
			<header class="entry-header">
				<h1 class="entry-title">About</h1>
			</header><!-- .entry-header -->

			<div class="entry-content">
				<p>This site is using the standard WordPress Theme Unit Test Data for <strong>content</strong>.</p>
				<p>The Theme Unit Test is a series of posts and pages that match up with a checklist on the WordPress codex.</p>
				<p>This site is using the standard WordPress Theme Unit Test Data for content. The Theme Unit Test is a series of posts and pages that match up with a checklist on the WordPress codex.</p>
				<p>You can use the data and checklist together to test your theme.</p>
			</div><!-- .entry-content -->
		</div><!-- .entry-container -->
	</article>';
}
endif; // parallax_frame_demo_hero_content


if ( ! function_exists( 'parallax_frame_post_page_category_hero_content' ) ) :
/**
 * This function to display hero posts content
 *
 * @param $options: parallax_frame_theme_options from customizer
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_post_page_category_hero_content( $options ) {
	global $post;

	$quantity   = $options['hero_content_number'];
	$no_of_post = 0; // for number of posts
	$post_list  = array();// list of valid post/page ids
	$type       = $options['hero_content_type'];
	$output     = '';

	$args = array(
		'orderby'             => 'post__in',
		'ignore_sticky_posts' => 1 // ignore sticky posts
	);

	//Get valid number of posts
	if ( 'hero-post-content' == $type || 'hero-page-content' == $type ) {
		for( $i = 1; $i <= $quantity; $i++ ){
			$post_id = '';

			if ( 'hero-post-content' == $type ) {
				$post_id = isset( $options['hero_content_post_' . $i] ) ? $options['hero_content_post_' . $i] : false;
				$args['post_type'] = 'post';
			}
			elseif ( 'hero-page-content' == $type ) {
				$post_id = isset( $options['hero_content_page_' . $i] ) ? $options['hero_content_page_' . $i] : false;
				$args['post_type'] = 'page';
			}

			if ( $post_id && '' != $post_id ) {
				$post_list = array_merge( $post_list, array( $post_id ) );

				$no_of_post++;
			}
		}

		$args['post__in'] = $post_list;
	}
	elseif ( 'hero-category-content' == $type ) {
		$no_of_post           = $quantity;
		$args['post_type'] = 'post';

		if ( is_array( $options['hero_content_select_category'] ) && ('0' != $options['hero_content_select_category'] ) ) {
			$category_list	= (array) $options['hero_content_select_category'];
			if ( defined( "ICL_LANGUAGE_CODE" ) ) {
			    $category = array();
			    foreach( $category_list as $cat ) {
			    	$category[] = apply_filters( 'wpml_object_id', $cat, 'category', true );
			    }
			    $category_list = $category;
			}
		}
		else {
			$category_list	= '0';
		}
		$args['category__in'] = $category_list;
	}

	if ( 0 == $no_of_post ) {
		return;
	}

	$args['posts_per_page'] = $no_of_post;

	$get_hero_posts         = new WP_Query( $args );

	$i=0;
	while ( $get_hero_posts->have_posts() ) {
		$get_hero_posts->the_post();

		$i++;

		$title_attribute = the_title_attribute( array( 'before' => esc_html__( 'Permalink to:', 'parallax-frame-pro' ), 'echo' => false ) );

		$output .= '
			<article id="post-' . $i . '" class="post-' . $i . ' hentry has-post-thumbnail">';

			//Default value if there is no first image
			$image = '<img class="pngfix wp-post-image" src="'.get_template_directory_uri().'/images/gallery/no-featured-image-1680x720.jpg" >';

			if ( has_post_thumbnail() ) {
				$image = get_the_post_thumbnail( $post->ID, 'parallax-frame-featured-content', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
			}
			else {
				//Get the first image in page, returns false if there is no image
				$first_image = parallax_frame_get_first_image( $post->ID, 'parallax-frame-hero-content', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );

				//Set value of image as first image if there is an image present in the page
				if ( '' != $first_image ) {
					$image = $first_image;
				}
			}

			$output .= '
				<figure class="featured-image">
					<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '">
					'. $image .'
					</a>
				</figure>';

			if ( $options['hero_content_enable_title'] || 'hide-content' != $options['hero_content_show'] ) {
			$output .= '
				<div class="entry-container">
					<header class="entry-header">
						<h1 class="entry-title">
							<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . the_title( '','', false ) . '</a>
						</h1>
					</header>';

				if ( 'excerpt' == $options['hero_content_show'] ) {
					//Show Excerpt
					$output .= '
					<div class="entry-content">
						<p>' . get_the_excerpt() . '</p>
					</div><!-- .entry-content -->';
				}
				elseif ( 'full-content' == $options['hero_content_show'] ) {
					//Show Content
					$content = apply_filters( 'the_content', get_the_content() );
					$content = str_replace( ']]>', ']]&gt;', $content );
					$output .= '<div class="entry-content">' . $content . '</div><!-- .entry-content -->';
				}
			}
			$output .= '
				</div><!-- .entry-container -->
			</article><!-- .post-'. $i .' -->';
		} //endwhile

	wp_reset_postdata();

	return $output;
}
endif; // parallax_frame_post_page_category_hero_content


if ( ! function_exists( 'parallax_frame_custom_hero_content' ) ) :
/**
 * This function to display hero posts content
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 * @uses set_transient
 *
 * @since Parallax Frame 1.0
 */
function parallax_frame_custom_hero_content( $options ) {
	$quantity = $options['hero_content_number'];
	$output   = '';

	for ( $i = 1; $i <= $quantity; $i++ ) {
		if ( !empty ( $options[ 'hero_content_target_' . $i ] ) ) {
			$target = '_blank';
		} else {
			$target = '_self';
		}

		//Checking Link
		if ( !empty ( $options[ 'hero_content_link_' . $i ] ) ) {
			//support qTranslate plugin
			if ( function_exists( 'qtrans_convertURL' ) ) {
				$link = qtrans_convertURL(  $options[ 'hero_content_link_' . $i ] );
			}
			else {
				$link =  $options[ 'hero_content_link_' . $i ];
			}
		}
		else {
			$link = '#';
		}

		//Checking Title
		if ( !empty ( $options[ 'hero_content_title_'. $i ] ) ) {
			$title = $options[ 'hero_content_title_'. $i ];
		}
		else {
			$title = '';
		}

		//Checking Content
		if ( !empty ( $options[ 'hero_content_content_'. $i ] ) ) {
			$content = $options[ 'hero_content_content_'. $i ];
		}
		else {
			$content = '';
		}

		$button_text   = '';
		$button_link   = '#';
		$button_target = '_self';

		//Checking Button Elements
		if ( !empty ( $options['hero_content_button_text_' . $i] ) ) {
			$button_text = $options['hero_content_button_text_' . $i];

			if ( !empty ( $options['hero_content_button_link_' . $i] ) ) {
				//support qTranslate plugin
				if ( function_exists( 'qtrans_convertURL' ) ) {
					$button_link = qtrans_convertURL(  $options['hero_content_button_link_' . $i] );
				}
				else {
					$button_link = $options['hero_content_button_link_' . $i];
				}
			}

			if ( !empty ( $options['hero_content_button_target_' . $i] ) ) {
				$button_target = '_blank';
			}
		}

		$output .= '
			<article id="image-'.$i.'" class="post hentry hero-image-content has-post-thumbnail">';
				if ( !empty ( $options[ 'hero_content_image_' . $i ] ) ) {
					$output .= '
					<figure class="featured-image">
						<a title="' . esc_attr( $title ) . '" href="' . esc_url( $link ) . '" target="' . esc_attr( $target ) . '">
							<img src="' . esc_url( $options[ 'hero_content_image_' . $i ] ) . '" class="wp-post-image" alt="' . esc_attr( $title ) . '" title="' . esc_attr( $title ) . '">
						</a>
					</figure>';
				}

				if ( '' != $title || '' != $content || '' != $button_text ) {
					$output .= '
					<div class="entry-container">';
					if ( '' != $title ) {
						$output .= '
						<header class="entry-header">
							<h1 class="entry-title">
								' . wp_kses_post( $title ) . '
							</h1>
						</header>';
					}
					if (  '' != $content || '' != $button_text ) {
						$output .= '
						<div class="entry-content">
							' . $content;

						if( '' != $button_text ) {
							$output .= '<span class="readmore"><a href="' . esc_url( $button_link ) . '" class="button" target="' . esc_attr( $button_target ) . '">'. esc_html( $button_text ) .'</a></span>';
						}

						$output .='</div>';
					}

					$output .= '
					</div><!-- .entry-container -->';
				}
			$output .= '
			</article><!-- .hero-custom-'.$i.' -->';
	}
	return $output;
}
endif; //parallax_frame_custom_content